// =================================================================================
//	AppConstants.h
// =================================================================================

#ifndef _H_AppConstants
#define _H_AppConstants
#pragma once

#include <PP_Types.h>
	
const ResIDT	ALRT_NoThreadManager		= 1000;
const ResIDT	ALRT_BrowserSetup			= 129;
const ResIDT	ALRT_Msg				= 130;

const short	BrowserSetup_OK			= 1;
const short	BrowserSetup_Cancel		= 2;

const ResIDT	PPob_AboutWindow			= 129;
const ResIDT	PPob_PreferencesWindow		= 130;

const PaneIDT	CAPT_Version				= 'ver.';
const PaneIDT	CAPT_Publisher				= 'publ';
const PaneIDT	ChasingArrow_IPC			= 'ipcb';
const PaneIDT	PopupButton_JapaneseFont	= 1000;
const PaneIDT	PopupButton_RomanFont		= 1001;

const OSType	AppType					= 'GBVI';
const OSType	NetscapeSign				= 'MOSS';

const MessageT	cmd_MemoryDebug		= 1001;
const MessageT	cmd_SetJapaneseFont	= 1100;
const MessageT	cmd_SetRomanFont		= 1101;

const UInt32	thTicksYield				= 2;  //  33 ms
const UInt32	thTicksForceSwitch			= 6;  // 100 ms
const UInt32	thTicksHeavyAlert			= 15; // 250 ms
const UInt32	thTicksPriorityWeight		= 60; //   1 sec
const UInt32	thDefaultPriority			= 4;
const UInt32	thMillsecDeadLock			= 30000;//30 sec

//#define THREAD_DEBUG_MSG

#endif // _H_AppConstants